# Deidentify (deid) Data

Data for best effort anonymization for medical images in Python.

[![DOI](https://zenodo.org/badge/94163984.svg)](https://zenodo.org/badge/latestdoi/94163984)

This data is supplementary to the [Deid](https://github.com/pydicom/deid) library and can be installed alongside it:

```bash
$ pip install deid-data
```

Please see our [Documentation](https://pydicom.github.io/deid/).

## Issues

If you have an issue with the data or want to request a new dataset, please do so on our [issues board](https://www.github.com/pydicom/deid-data/issues).
For all other issues, please post to [deid-issues](https://www.github.com/pydicom/deid/issues)
